==> libreoffice_4.2.8.orig.tar.xz: libreoffice-4.2.8/scripting/java/com/sun/star/script/framework/provider/NoSuitableClassLoaderException.java <==
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

package com.sun.star.script.framework.provider;

public class NoSuitableClassLoaderException extends Exception
{
    /**
     * Constructs an <code>NoSuitableClassLoaderException</code> with <code>null</code>
     * as its error detail message.
     */
    public NoSuitableClassLoaderException()
    {
        super();
    }
    /**
     * Constructs an <code>NoSuitBaleClassLoaderException</code> with the specified detail
     * message. The error message string <code>s</code> can later be
     * retrieved by the <code>{@link java.lang.Throwable#getMessage}</code>
     * method of class <code>java.lang.Throwable</code>.
     *
     * @param   s   the detail message.
     */
    public NoSuitableClassLoaderException(String s)
    {
        super(s);
    }

}

==> libreoffice-5.4.0.3.tar.xz: libreoffice-5.4.0.3/scripting/java/com/sun/star/script/framework/provider/NoSuitableClassLoaderException.java <==
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

package com.sun.star.script.framework.provider;

public class NoSuitableClassLoaderException extends Exception {

    /**
     * Constructs an <code>NoSuitableClassLoaderException</code> with <code>null</code>
     * as its error detail message.
     */
    public NoSuitableClassLoaderException() {
        super();
    }

    /**
     * Constructs an <code>NoSuitBaleClassLoaderException</code> with the specified detail
     * message. The error message string <code>s</code> can later be
     * retrieved by the <code>{@link java.lang.Throwable#getMessage}</code>
     * method of class <code>java.lang.Throwable</code>.
     *
     * @param   s   the detail message.
     */
    public NoSuitableClassLoaderException(String s) {
        super(s);
    }
}
